@@ -1,26 +1,34 @@
 # coding: utf-8
-from django.db import models
-from django.db.models import Q
+"""
+.. module:: datalogging.api
+.. moduleauthor:: Andrey Torsunov <torsunov@bars-open.ru>
 
-from m3_legacy.middleware import get_thread_data
+"""
 
 __author__ = 'Andrey Torsunov'
 __contact__ = 'torsunov@bars-open.com'
 __docformat__ = 'restructuredtext'
 
+from django.db import models
+from django.db.models import Q
+
+from m3_legacy.middleware import get_thread_data
+
 
 def get_request():
-    u""" Получение текущего запроса. """
+    u"""Получение текущего запроса.
+    """
     _thread_locals = get_thread_data()
     try:
-        request =  _thread_locals.wref_request()
+        request = _thread_locals.wref_request()
     except AttributeError:
         request = None
     return request
 
 
 def get_request_token():
-    u""" Получение токена текущего запроса. """
+    u"""Получение токена текущего запроса.
+    """
     _thread_locals = get_thread_data()
     return getattr(_thread_locals, 'request_token', None)
 
