@@ -1,5 +1,4 @@
 # coding: utf-8
-import os
 import uuid
 import datetime
 
@@ -9,7 +8,7 @@ from json_field.fields import JSONEncoder
 
 from .helpers import get_snapshot
 from .enums import EventCode
-from .api import get_user_ip, get_request_token, get_request
+from datalogging.api import get_user_ip, get_request_token, get_request
 from .signals import msg_for_log_signal, log_context_signal, \
     post_snapshot_signal, post_system_event_signal
 
@@ -82,7 +81,6 @@ class DataLog(models.Model):
     request_token = models.CharField(
         u'Токен запроса', max_length=64, db_index=True)
 
-
     def __init__(self, *a, **kw):
         u""" Инициализация записи лога.
 
@@ -225,14 +223,11 @@ class DataLog(models.Model):
             state_diff -= cur_snapshot
 
             for attr_name, old_value in state_diff:
-                try:
-                    alias, field_diff, verbose = cls._diff_field(
-                        instance, attr_name, old_value, name_map
-                    )
-                    result_diff[alias] = field_diff
-                    verbose_names[alias] = verbose
-                except models.FieldDoesNotExist:
-                    pass
+                alias, field_diff, verbose = cls._diff_field(
+                    instance, attr_name, old_value, name_map
+                )
+                result_diff[alias] = field_diff
+                verbose_names[alias] = verbose
 
             log_rec.context_data['diff'] = result_diff
             log_rec.context_data['field_names'] = verbose_names
@@ -270,7 +265,8 @@ class DataLog(models.Model):
 
         # Если хотя бы один обработчик вернет False, то это будет
         # означать, что запись с логом не нужно сохранять.
-        signal_results = post_system_event_signal.send(cls, log_record=log_rec, **kw)
+        signal_results = post_system_event_signal.send(cls, log_record=log_rec,
+            **kw)
         if False not in signal_results:
             log_rec.save()
 
